package com.ruoyi.web.yh.report.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.web.yh.report.mapper.ReportMapper;
import com.ruoyi.web.yh.report.domain.Report;
import com.ruoyi.web.yh.report.domain.ReportVO;
import com.ruoyi.web.yh.report.domain.ReportQuery;
import com.ruoyi.web.yh.report.service.IReportService;

/**
 * 报表Service业务层处理
 *
 * @author ruoyi
 * @date 2024-10-18
 */
@Service
public class ReportServiceImpl implements IReportService
{
    @Autowired
    private ReportMapper reportMapper;

    /**
     * 查询报表
     *
     * @param reportId 报表主键
     * @return 报表
     */
    @Override
    public ReportVO selectReportByReportId(Long reportId)
    {
        return reportMapper.selectReportByReportId(reportId);
    }

    /**
     * 查询报表列表
     *
     * @param report 报表
     * @return 报表
     */
    @Override
    public List<ReportVO> selectReportList(ReportQuery report)
    {
        return reportMapper.selectReportList(report);
    }

    /**
     * 新增报表
     *
     * @param report 报表
     * @return 结果
     */
    @Override
    public int insertReport(Report report)
    {
        report.setCreateTime(DateUtils.getNowDate());
        return reportMapper.insertReport(report);
    }

    /**
     * 修改报表
     *
     * @param report 报表
     * @return 结果
     */
    @Override
    public int updateReport(Report report)
    {
        report.setUpdateTime(DateUtils.getNowDate());
        return reportMapper.updateReport(report);
    }

    /**
     * 批量删除报表
     *
     * @param reportIds 需要删除的报表主键
     * @return 结果
     */
    @Override
    public int deleteReportByReportIds(Long[] reportIds)
    {
        return reportMapper.deleteReportByReportIds(reportIds);
    }

    /**
     * 删除报表信息
     *
     * @param reportId 报表主键
     * @return 结果
     */
    @Override
    public int deleteReportByReportId(Long reportId)
    {
        return reportMapper.deleteReportByReportId(reportId);
    }
}
